@@ -50,11 +50,12 @@ class XmasTree(object):
                     self.tree = self.tree.replace(i, colored(choice(self.ornament), choice(COLORS.keys()), attrs=['blink', 'bold']))
             self.tree = self.tree.replace('/', colored('/', 'green', attrs=['bold'])).replace('\\', colored('\\', 'green', attrs=['bold']))
             self.tree = self.tree.replace('*', colored('*', 'green', attrs=['bold'])).replace('_', colored('_', 'green', attrs=['bold']))
+            self.tree = self.tree.replace('|', colored('|', 'green', attrs=['bold']))
 
     def show(self):
         print self.tree
         print
-        print colored(self.greeting.center(self.center), 'red', attrs=['bold', 'underline'])
+        print colored(self.greeting.center(self.center + 8), 'red', attrs=['bold', 'reverse', 'underline'])
 
 def main():
     import argparse
